==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Artículo &apos;%1&apos; ha sido añadido a su lista de favoritos.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>Público objetivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimensión</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Nivel de detalle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspectiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>Navegador de la biblioteca</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>Icono</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>Elija la carpeta de origen</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation>Página %1 de %2</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>Regeneración de los iconos...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Fichero:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Carpeta:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Atribución:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Actualización de índice:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Actualización de índice...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Interrumpir</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Actualización de índice:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>DB error</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;Insertar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Editar archivos de script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Abrir archivo &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Editar...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Fichero</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Muestran con %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Eliminar de mis favoritos</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Agregar a favoritos</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Regenerar &amp;icono</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Regeneración de los iconos</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferencias</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sincronización</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Actualizar índice de búsqueda en el arranque</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Opciones de visualización</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Icono tamaño:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Modo de visualización:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Número de elementos mostrados
en los resultados de búsqueda:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Fuentes de la biblioteca</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Añadir...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>Explorador de la &amp;Biblioteca</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Sistema de archivos</translation>
    </message>
    <message>
        <location line="+252"/>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Reinicializar</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Update DB from file system</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Artículo &apos;%1&apos; ha sido añadido a su lista de favoritos.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>Público objetivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimensión</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Nivel de detalle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspectiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Navegador de la biblioteca</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Icono</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Elija la carpeta de origen</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Página %1 de %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Regeneración de los iconos...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Fichero:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Carpeta:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Atribución:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Actualización de índice:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Actualización de índice...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Interrumpir</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Actualización de índice:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>DB error</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Fuente retirado de biblioteca: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Forzada de actualización de base de datos.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;Insertar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Editar archivos de script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Abrir archivo &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Editar...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Fichero</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Muestran con %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Eliminar de mis favoritos</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Agregar a favoritos</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Regenerar &amp;icono</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Regeneración de los iconos</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferencias</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sincronización</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Actualizar índice de búsqueda en el arranque</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Opciones de visualización</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Icono tamaño:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Modo de visualización:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Número de elementos mostrados
en los resultados de búsqueda:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Fuentes de la biblioteca</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Añadir...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>Explorador de la &amp;Biblioteca</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Sistema de archivos</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Tags</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Look for:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Reinicializar</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+162"/>
        <source>Insert selected item into drawing</source>
        <translation>Insertar elemento seleccionado en el dibujo</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
